@@ -3,7 +3,7 @@ package RDF::Simple::NS;
 use strict;
 
 our
-$VERSION = do { my @r = (q$Revision: 1.3 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.4 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };
 
 sub new {
         my $class = shift;
@@ -40,32 +40,42 @@ sub qname {
 }
 
 # Retrieve or add to the entity to namespace lookup hash
-sub lookup {
-    my ($self,%add) = @_;
-    $self->{_lookup} ||=
+sub lookup
+  {
+  my $self = shift;
+  my %add;
+  if (ref $_[0] eq 'HASH')
     {
-        foaf => 'http://xmlns.com/foaf/0.1/',
-        dc => 'http://purl.org/dc/elements/1.1/',
-        rdfs => "http://www.w3.org/2000/01/rdf-schema#",
-        daml => 'http://www.w3.org/2001/10/daml+oil#',
-        space => 'http://frot.org/space/0.1/',
-        geo => 'http://www.w3.org/2003/01/geo/wgs84_pos#',
-        rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
-        owl => 'http://www.w3.org/2002/07/owl#',
-        ical => 'http://www.w3.org/2002/12/cal/ical#',
-        dcterms=>"http://purl.org/dc/terms/",
-        wiki=>"http://purl.org/rss/1.0/modules/wiki/",
-        chefmoz=>"http://chefmoz.org/rdf/elements/1.0/",
-        wot => "http://xmlns.com/wot/0.1/",
-        cng => 'http://iconocla.st/cng#',
-	status => 'http://www.w3.org/2003/06/sw-vocab-status/ns#',
-         };
-
-    foreach (keys %add) {
-        $self->{_lookup}->{$_} = $add{$_};
+    %add = %{$_[0]};
     }
-    return %{$self->{_lookup}};
-}
+  else
+    {
+    %add = @_;
+    }
+  $self->{_lookup} ||=
+    {
+     foaf => 'http://xmlns.com/foaf/0.1/',
+     dc => 'http://purl.org/dc/elements/1.1/',
+     rdfs => "http://www.w3.org/2000/01/rdf-schema#",
+     daml => 'http://www.w3.org/2001/10/daml+oil#',
+     space => 'http://frot.org/space/0.1/',
+     geo => 'http://www.w3.org/2003/01/geo/wgs84_pos#',
+     rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
+     owl => 'http://www.w3.org/2002/07/owl#',
+     ical => 'http://www.w3.org/2002/12/cal/ical#',
+     dcterms=>"http://purl.org/dc/terms/",
+     wiki=>"http://purl.org/rss/1.0/modules/wiki/",
+     chefmoz=>"http://chefmoz.org/rdf/elements/1.0/",
+     wot => "http://xmlns.com/wot/0.1/",
+     cng => 'http://iconocla.st/cng#',
+     status => 'http://www.w3.org/2003/06/sw-vocab-status/ns#',
+    };
+  foreach (keys %add)
+    {
+    $self->{_lookup}->{$_} = $add{$_};
+    } # foreach
+  return %{$self->{_lookup}};
+  } # lookup
 
 sub entity_to_namespace {
     my ($self,$entity) = @_;
